Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(499)

Unified Diff: chrome/browser/ui/gtk/tabs/dragged_view_gtk.cc

Issue 23531053: ui/base/animation -> ui/gfx/animation (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Merge 2 trunk Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/gtk/tabs/dragged_view_gtk.h ('k') | chrome/browser/ui/gtk/tabs/tab_renderer_gtk.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/gtk/tabs/dragged_view_gtk.cc
diff --git a/chrome/browser/ui/gtk/tabs/dragged_view_gtk.cc b/chrome/browser/ui/gtk/tabs/dragged_view_gtk.cc
index 29b41f7578c94c7750ea2e5123ef07498a1e82cc..93811c538d7824ef555f2fb5b94922e498edae4d 100644
--- a/chrome/browser/ui/gtk/tabs/dragged_view_gtk.cc
+++ b/chrome/browser/ui/gtk/tabs/dragged_view_gtk.cc
@@ -216,7 +216,7 @@ void DraggedViewGtk::AnimateToBounds(const gfx::Rect& bounds,
animation_end_bounds_ = bounds;
close_animation_.SetSlideDuration(kAnimateToBoundsDurationMs);
- close_animation_.SetTweenType(ui::Tween::EASE_OUT);
+ close_animation_.SetTweenType(gfx::Tween::EASE_OUT);
if (!close_animation_.IsShowing()) {
close_animation_.Reset();
close_animation_.Show();
@@ -224,9 +224,9 @@ void DraggedViewGtk::AnimateToBounds(const gfx::Rect& bounds,
}
////////////////////////////////////////////////////////////////////////////////
-// DraggedViewGtk, ui::AnimationDelegate implementation:
+// DraggedViewGtk, gfx::AnimationDelegate implementation:
-void DraggedViewGtk::AnimationProgressed(const ui::Animation* animation) {
+void DraggedViewGtk::AnimationProgressed(const gfx::Animation* animation) {
int delta_x = (animation_end_bounds_.x() - animation_start_bounds_.x());
int x = animation_start_bounds_.x() +
static_cast<int>(delta_x * animation->GetCurrentValue());
@@ -235,11 +235,11 @@ void DraggedViewGtk::AnimationProgressed(const ui::Animation* animation) {
gdk_window_move(gdk_window, x, y);
}
-void DraggedViewGtk::AnimationEnded(const ui::Animation* animation) {
+void DraggedViewGtk::AnimationEnded(const gfx::Animation* animation) {
animation_callback_.Run();
}
-void DraggedViewGtk::AnimationCanceled(const ui::Animation* animation) {
+void DraggedViewGtk::AnimationCanceled(const gfx::Animation* animation) {
AnimationEnded(animation);
}
« no previous file with comments | « chrome/browser/ui/gtk/tabs/dragged_view_gtk.h ('k') | chrome/browser/ui/gtk/tabs/tab_renderer_gtk.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698